# Documentation

This directory contains comprehensive documentation for GraphQL CSV Ingest.

## 📚 Documentation Structure

```
docs/
├── README.md           # This file
├── assets/             # Images, diagrams, and media
├── api/                # API documentation
├── guides/             # User guides and tutorials
├── examples/           # Code examples
└── development/        # Development documentation
```

## 📖 Available Documentation

### User Guides
- [Getting Started](../QUICKSTART.md) - Quick setup and basic usage
- [CLI Reference](./guides/cli-reference.md) - Complete CLI command documentation
- [GraphQL API](./api/graphql.md) - GraphQL schema and query examples
- [Configuration](./guides/configuration.md) - Environment and setup options

### Developer Documentation
- [Contributing](../CONTRIBUTE.md) - How to contribute to the project
- [Development Setup](./development/setup.md) - Setting up development environment
- [Architecture](./development/architecture.md) - System design and components
- [Testing](./development/testing.md) - Testing strategies and guidelines

### Examples
- [Basic Usage](../examples/basic/) - Simple CSV ingestion examples
- [Advanced Queries](../examples/advanced/) - Complex GraphQL query examples
- [Docker Deployment](../examples/docker/) - Container deployment examples

## 🚀 Quick Links

- [Project README](../README.md)
- [Changelog](../CHANGELOG.md)
- [License](../LICENSE)

## 📝 Contributing to Documentation

Documentation improvements are always welcome! Please see our [contribution guidelines](../CONTRIBUTE.md) for more information.

When contributing documentation:
1. Keep content clear and concise
2. Include practical examples
3. Test all code examples
4. Update relevant links and references
5. Follow the existing style and structure

---

**Need help?** Open an [issue](../../issues) or check our [contribution guide](../CONTRIBUTE.md). 